SeedKitAnalyticsFactory class abstract

Класс для инициализации Sentry в корне проекта.

Future<void> main() async {
  await SeedKitAnalyticsFactory.init(
    sentryDsn: 'sentry_dsn',
    appRunner: () async {
      WidgetsFlutterBinding.ensureInitialized();

      // initialization of modules

      runApp(App());
    },
  );
}

Constructors

SeedKitAnalyticsFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init({required FutureOr<void> appRunner()?, String sentryDsn = ''}) Future<void>