SeedKitAnalyticsHandler class abstract

Класс handler для отправки краш аналитики в Sentry

Constructors

SeedKitAnalyticsHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

captureException(dynamic exception, {StackTrace? stackTrace}) → void
captureMessage(String message, {List? params}) → void
removeUser() → void
setUser(String userId) → void